@@ -12,7 +12,7 @@ def data():
 
 
 def test_extract_data_extracts_all_info_layers(data):
-    for name in ("20", "25", "30", "35", "40"):
+    for name in ("20", "25", "30", "35", "40", "extra"):
         assert name in data
 
 
